# Café Plätschwiesle

![Alt vue](https://img.shields.io/badge/Framework-Vue3-informational?style=for-the-badge&logo=vuedotjs&color=4FC08D)
![Alt typescript](https://img.shields.io/badge/Language-Typescript-informational?style=for-the-badge&logo=typescript&color=3178C6)
![Alt go](https://img.shields.io/badge/Language-Go-informational?style=for-the-badge&logo=go&color=00ADD8)

## docker-compose example

```yaml
services:
  cafe:
    image: ghcr.io/flohoss/cafe-plaetschwiesle:latest
    container_name: cafe
    restart: unless-stopped
    environment:
      - PUID=1000
      - PGID=1000
      - ALLOWED_HOSTS=http://localhost:5000,https://home.example.com
      - SWAGGER=true
      - LOG_LEVEL=info # trace,debug,info,warn,error,fatal,panic
    volumes:
      - ./storage:/app/storage
    ports:
      - '127.0.0.1:5000:5000'
```

## docker-compose example with MariaDB as database

```yaml
networks:
  net:
    external: false

services:
  cafe-db:
    image: lscr.io/linuxserver/mariadb:latest
    container_name: cafe-db
    restart: unless-stopped
    environment:
      - PUID=1000
      - PGID=1000
      - MYSQL_ROOT_PASSWORD=root
      - TZ=Europe/Berlin
      - MYSQL_DATABASE=db
      - MYSQL_USER=user
      - MYSQL_PASSWORD=password
    volumes:
      - ./db:/config
    expose:
      - 3306
    networks:
      - net

  cafe:
    image: ghcr.io/flohoss/cafe-plaetschwiesle:latest
    container_name: cafe
    restart: unless-stopped
    depends_on:
      - cafe-db
    environment:
      - PUID=1000
      - PGID=1000
      - ALLOWED_HOSTS=http://localhost:5000,https://home.example.com
      - SWAGGER=true
      - LOG_LEVEL=info # trace,debug,info,warn,error,fatal,panic
      - MYSQL_URL=cafe-db:3306
      - MYSQL_USER=user
      - MYSQL_PASSWORD=password
      - MYSQL_DATABASE=db
    volumes:
      - ./storage:/app/storage
    ports:
      - '127.0.0.1:5000:5000'
    networks:
      - net
```
